@@ -410,7 +410,7 @@ class Sequential():
         else:
             raise ValueError("invalid value for 'verbose'")
     
-    def fit(self, cost_fn, epochs = 1000, lr = 0.1, momentum = None, verbose = 1, live_stats = None):
+    def fit(self, cost_fn, epochs = 1000, lr = 0.1, momentum = None, verbose = 1, live_stats = None, extension = None):
         if live_stats == None:
             live_stats = LiveStats()
         elif live_stats == -1:
@@ -484,6 +484,9 @@ class Sequential():
                         live_stats.run(self, figure)
                             
                 self.verbose(verbose, epoch, epochs, start)
+                
+                if callable(extension):
+                    extension()
         else:
             for epoch in range(epochs):
                 self.forward()
@@ -501,6 +504,9 @@ class Sequential():
                         live_stats.run(self, figure)
                         
                 self.verbose(verbose, epoch, epochs, start)
+                
+                if callable(extension):
+                    extension()
         
     def results(self):
         if self.__is_trained__ == True:
