@@ -199,21 +199,22 @@ class DGImputer():
         import numpy as np
         self.diffs = np.zeros(shape=self.X.shape)
         self.scores = np.zeros(shape=(self.X.shape[0], 1))
-        for i in range(len(self.X[0,:])):
-            self.diffs[pos[0],i] = self.X[pos[0], i]
+        for i in range(len(self.X_copy[0,:])):
+            self.diffs[pos[0], i] = self.X_copy[pos[0], i]
             
-        for i in range(len(self.X[:,0])):
-            for j in range(len(self.X[0,:])):
+        for i in range(len(self.X_copy[:,0])):
+            for j in range(len(self.X_copy[0,:])):
                 if j != pos[1]: 
-                    self.diffs[i,j] = np.absolute(self.X[pos[0], j] - self.X[i,j])
+                    self.diffs[i,j] = np.absolute(self.X_copy[pos[0], j] - self.X_copy[i,j])
                     
         for i in range(self.scores.shape[0]):
             self.scores[i] = np.sum(self.diffs[i])
         
-        return [np.argsort(self.scores, axis=0)[i] for i in range(self.scores.shape[0]//2) if np.isnan(self.X[np.argsort(self.scores, axis=0)[i][0], self.col]) == False]
+        return [np.argsort(self.scores, axis=0)[i] for i in range(self.scores.shape[0]//2) if np.isnan(self.X_copy[np.argsort(self.scores, axis=0)[i][0], self.col]) == False]
         
     def transform(self, X, column):
         import numpy as np
+        self.X_copy = np.copy(X)
         self.X = np.copy(X)
         self.col = column
         self.nans = []
